# aeneas.cwave

**aeneas.cwave** is a Python C extension to read WAVE files.

## API

See the [__init__.py](__init__.py) file.

## Compiling the Python C extension locally

```bash
$ python cwave_setup.py build_ext --inplace
```

## Compiling the pure C driver program

```bash
$ bash 000_compile_driver.sh
```



